# Vpnroulette

## 🚨NOTE: vpnroulette client is in BETA🚨

[![Pylint](https://github.com/vpnroulette/vpnr-client/actions/workflows/tests.yml/badge.svg)](https://github.com/vpnroulette/vpnr-client/actions/workflows/tests.yml)

![vpnroulette logo](logo/vpnroulette-logo.png)

This is our official command line client build with ❤️  in python

<!-- START doctoc generated TOC please keep comment here to allow auto update -->
<!-- DON'T EDIT THIS SECTION, INSTEAD RE-RUN doctoc TO UPDATE -->
**Table of Contents**  *generated with [DocToc](https://github.com/thlorenz/doctoc)*

- [Vpnroulette](#vpnroulette)
  - [🚨NOTE: vpnroulette client is in BETA🚨](#note-vpnroulette-client-is-in-beta)
- [**Requirements**](#requirements)
- [**Intallation**](#intallation)
- [Usage](#usage)
  - [Disclaimer](#disclaimer)
- [**Community**](#community)

<!-- END doctoc generated TOC please keep comment here to allow auto update -->

# **Requirements**

* python3
* python3-pip
* Your email and password

# **Intallation**

```bash
pip3 install vpnroulette
```

# Usage

```bash
vpnroulette # interactive mode
```
## Disclaimer

```bash
vpnroulette --disclaimer
```

# **Community**

Join our community and discover how to become a node and build an unstoppable VPN network all around the world.

- **Website:** <https://vpnroulette.com>
- **Discord server:** <https://discord.gg/6CCD6P3T>  
